@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+from unittest import mock
+
 from z3c.dependencychecker.package import Package
 from z3c.dependencychecker.report import Report
 from z3c.dependencychecker.tests.utils import write_source_file_at
-import mock
 
 
 def test_print_header_nothing(capsys):
@@ -44,11 +44,7 @@ def test_missing_requirements_nothing(capsys):
 
 def test_missing_requirements(capsys, minimal_structure):
     path, package_name = minimal_structure
-    write_source_file_at(
-        (path, package_name),
-        '__init__.py',
-        'import this.package'
-    )
+    write_source_file_at((path, package_name), '__init__.py', 'import another.package')
 
     package = Package(path)
     package.inspect()
@@ -56,9 +52,8 @@ def test_missing_requirements(capsys, minimal_structure):
     report.missing_requirements()
     out, err = capsys.readouterr()
 
-    assert 'Missing requirements\n' \
-           '====================' in out
-    assert 'this.package' in out
+    assert 'Missing requirements\n====================' in out
+    assert 'another.package' in out
 
 
 def test_missing_requirements_with_user_mapping(capsys, minimal_structure):
@@ -66,20 +61,22 @@ def test_missing_requirements_with_user_mapping(capsys, minimal_structure):
     write_source_file_at(
         (path, package_name),
         '__init__.py',
-        'import Products.Five.browser.views.BrowserView'
+        'import Products.Five.browser.views.BrowserView',
     )
     write_source_file_at(
-        (path, '{0}.egg-info'.format(package_name)),
+        (path, f'{package_name}.egg-info'),
         'requires.txt',
         'Zope2',
     )
     write_source_file_at(
-        (path, ),
+        (path,),
         'pyproject.toml',
-        '\n'.join([
-            '[tool.dependencychecker]',
-            'Zope2 = ["Four", "Products.Five", "Three" ]',
-        ]),
+        '\n'.join(
+            [
+                '[tool.dependencychecker]',
+                'Zope2 = ["Four", "Products.Five", "Three" ]',
+            ]
+        ),
     )
 
     package = Package(path)
@@ -88,8 +85,7 @@ def test_missing_requirements_with_user_mapping(capsys, minimal_structure):
     report.missing_requirements()
     out, err = capsys.readouterr()
 
-    assert 'Missing requirements\n' \
-           '====================' not in out
+    assert 'Missing requirements\n====================' not in out
     assert 'Products.Five' not in out
     assert 'Zope2' not in out
 
@@ -99,15 +95,17 @@ def test_missing_requirements_with_ignored_packages(capsys, minimal_structure):
     write_source_file_at(
         (path, package_name),
         '__init__.py',
-        'import Products.Five.browser.views.BrowserView'
+        'import Products.Five.browser.views.BrowserView',
     )
     write_source_file_at(
-        (path, ),
+        (path,),
         'pyproject.toml',
-        '\n'.join([
-            '[tool.dependencychecker]',
-            'ignore-packages = ["Four", "Products.Five", "Three" ]',
-        ]),
+        '\n'.join(
+            [
+                '[tool.dependencychecker]',
+                'ignore-packages = ["Four", "Products.Five", "Three" ]',
+            ]
+        ),
     )
 
     package = Package(path)
@@ -116,8 +114,7 @@ def test_missing_requirements_with_ignored_packages(capsys, minimal_structure):
     report.missing_requirements()
     out, err = capsys.readouterr()
 
-    assert 'Missing requirements\n' \
-           '====================' not in out
+    assert 'Missing requirements\n====================' not in out
     assert 'Products.Five' not in out
     assert 'Four' not in out
     assert 'Three' not in out
@@ -133,7 +130,7 @@ def test_missing_test_requirements(capsys, minimal_structure):
     write_source_file_at(
         (path, package_name, 'tests'),
         '__init__.py',
-        'import this.package',
+        'import another.package',
     )
 
     package = Package(path)
@@ -142,15 +139,11 @@ def test_missing_test_requirements(capsys, minimal_structure):
     report.missing_test_requirements()
     out, err = capsys.readouterr()
 
-    assert 'Missing test requirements\n' \
-           '=========================' in out
-    assert 'this.package' in out
+    assert 'Missing test requirements\n=========================' in out
+    assert 'another.package' in out
 
 
-def test_missing_test_requirements_with_user_mapping(
-    capsys,
-    minimal_structure
-):
+def test_missing_test_requirements_with_user_mapping(capsys, minimal_structure):
     path, package_name = minimal_structure
     write_source_file_at(
         (path, package_name),
@@ -160,20 +153,17 @@ def test_missing_test_requirements_with_user_mapping(
     write_source_file_at(
         (path, package_name, 'tests'),
         '__init__.py',
-        'import Products.Five.browser.views.BrowserView'
+        'import Products.Five.browser.views.BrowserView',
     )
     write_source_file_at(
-        (path, '{0}.egg-info'.format(package_name)),
+        (path, f'{package_name}.egg-info'),
         'requires.txt',
         'Zope2',
     )
     write_source_file_at(
-        (path, ),
+        (path,),
         'pyproject.toml',
-        '\n'.join([
-            '[tool.dependencychecker]',
-            'Zope2 = ["Products.Five" ]',
-        ]),
+        '\n'.join(['[tool.dependencychecker]', 'Zope2 = ["Products.Five" ]']),
     )
 
     package = Package(path)
@@ -183,15 +173,13 @@ def test_missing_test_requirements_with_user_mapping(
     out, err = capsys.readouterr()
 
     assert '' == out
-    assert 'Missing requirements\n' \
-           '====================' not in out
+    assert 'Missing requirements\n====================' not in out
     assert 'Products.Five' not in out
     assert 'Zope2' not in out
 
 
 def test_missing_test_requirements_with_user_mapping_on_test_extra(
-    capsys,
-    minimal_structure
+    capsys, minimal_structure
 ):
     path, package_name = minimal_structure
     write_source_file_at(
@@ -202,23 +190,17 @@ def test_missing_test_requirements_with_user_mapping_on_test_extra(
     write_source_file_at(
         (path, package_name, 'tests'),
         '__init__.py',
-        'import Products.Five.browser.views.BrowserView'
+        'import Products.Five.browser.views.BrowserView',
     )
     write_source_file_at(
-        (path, '{0}.egg-info'.format(package_name)),
+        (path, f'{package_name}.egg-info'),
         'requires.txt',
-        '\n'.join([
-            '[test]',
-            'Zope2',
-        ]),
+        '\n'.join(['[test]', 'Zope2']),
     )
     write_source_file_at(
-        (path, ),
+        (path,),
         'pyproject.toml',
-        '\n'.join([
-            '[tool.dependencychecker]',
-            'Zope2 = ["Products.Five" ]',
-        ]),
+        '\n'.join(['[tool.dependencychecker]', 'Zope2 = ["Products.Five" ]']),
     )
 
     package = Package(path)
@@ -228,16 +210,12 @@ def test_missing_test_requirements_with_user_mapping_on_test_extra(
     out, err = capsys.readouterr()
 
     assert '' == out
-    assert 'Missing requirements\n' \
-           '====================' not in out
+    assert 'Missing requirements\n====================' not in out
     assert 'Products.Five' not in out
     assert 'Zope2' not in out
 
 
-def test_missing_test_requirements_with_ignored_packages(
-    capsys,
-    minimal_structure
-):
+def test_missing_test_requirements_with_ignored_packages(capsys, minimal_structure):
     path, package_name = minimal_structure
     write_source_file_at(
         (path, package_name),
@@ -247,15 +225,17 @@ def test_missing_test_requirements_with_ignored_packages(
     write_source_file_at(
         (path, package_name, 'tests'),
         '__init__.py',
-        'import Products.Five.browser.views.BrowserView'
+        'import Products.Five.browser.views.BrowserView',
     )
     write_source_file_at(
-        (path, ),
+        (path,),
         'pyproject.toml',
-        '\n'.join([
-            '[tool.dependencychecker]',
-            'ignore-packages = ["Products.Five" ]',
-        ]),
+        '\n'.join(
+            [
+                '[tool.dependencychecker]',
+                'ignore-packages = ["Products.Five" ]',
+            ]
+        ),
     )
 
     package = Package(path)
@@ -265,8 +245,7 @@ def test_missing_test_requirements_with_ignored_packages(
     out, err = capsys.readouterr()
 
     assert '' == out
-    assert 'Missing requirements\n' \
-           '====================' not in out
+    assert 'Missing requirements\n====================' not in out
     assert 'Products.Five' not in out
 
 
@@ -284,15 +263,12 @@ def test_unneeded_requirements(capsys, minimal_structure):
     report.unneeded_requirements()
     out, err = capsys.readouterr()
 
-    assert 'Unneeded requirements\n' \
-           '=====================' in out
+    assert 'Unneeded requirements\n=====================' in out
     assert 'one' in out
     assert 'two' in out
 
 
-def test_unneeded_requirements_with_ignored_packages(
-        capsys,
-        minimal_structure):
+def test_unneeded_requirements_with_ignored_packages(capsys, minimal_structure):
     path, package_name = minimal_structure
     write_source_file_at(
         (path, package_name),
@@ -300,12 +276,14 @@ def test_unneeded_requirements_with_ignored_packages(
         'import this.package',
     )
     write_source_file_at(
-        (path, ),
+        (path,),
         'pyproject.toml',
-        '\n'.join([
-            '[tool.dependencychecker]',
-            'ignore-packages = ["one" ]',
-        ]),
+        '\n'.join(
+            [
+                '[tool.dependencychecker]',
+                'ignore-packages = ["one" ]',
+            ]
+        ),
     )
 
     package = Package(path)
@@ -314,15 +292,12 @@ def test_unneeded_requirements_with_ignored_packages(
     report.unneeded_requirements()
     out, err = capsys.readouterr()
 
-    assert 'Unneeded requirements\n' \
-           '=====================' in out
+    assert 'Unneeded requirements\n=====================' in out
     assert 'one' not in out
     assert 'two' in out
 
 
-def test_unneeded_requirements_with_user_mapping(
-        capsys,
-        minimal_structure):
+def test_unneeded_requirements_with_user_mapping(capsys, minimal_structure):
     path, package_name = minimal_structure
     write_source_file_at(
         (path, package_name),
@@ -330,21 +305,14 @@ def test_unneeded_requirements_with_user_mapping(
         'from BTrees import Tree',
     )
     write_source_file_at(
-        (path, ),
+        (path,),
         'pyproject.toml',
-        '\n'.join([
-            '[tool.dependencychecker]',
-            '"ZODB3" = ["BTrees" ]',
-        ]),
+        '\n'.join(['[tool.dependencychecker]', '"ZODB3" = ["BTrees" ]']),
     )
     write_source_file_at(
-        (path, '{0}.egg-info'.format(package_name), ),
+        (path, f'{package_name}.egg-info'),
         'requires.txt',
-        '\n'.join([
-            'ZODB3',
-            'setuptools',
-            'one',
-        ]),
+        '\n'.join(['ZODB3', 'setuptools', 'one']),
     )
 
     package = Package(path)
@@ -353,15 +321,12 @@ def test_unneeded_requirements_with_user_mapping(
     report.unneeded_requirements()
     out, err = capsys.readouterr()
 
-    assert 'Unneeded requirements\n' \
-           '=====================' in out
+    assert 'Unneeded requirements\n=====================' in out
     assert 'ZODB3' not in out
     assert 'one' in out
 
 
-def test_unneeded_requirements_with_user_mapping2(
-        capsys,
-        minimal_structure):
+def test_unneeded_requirements_with_user_mapping2(capsys, minimal_structure):
     path, package_name = minimal_structure
     write_source_file_at(
         (path, package_name),
@@ -369,21 +334,14 @@ def test_unneeded_requirements_with_user_mapping2(
         'from Plone import Tree',
     )
     write_source_file_at(
-        (path, ),
+        (path,),
         'pyproject.toml',
-        '\n'.join([
-            '[tool.dependencychecker]',
-            '"ZODB3" = ["BTrees" ]',
-        ]),
+        '\n'.join(['[tool.dependencychecker]', '"ZODB3" = ["BTrees" ]']),
     )
     write_source_file_at(
-        (path, '{0}.egg-info'.format(package_name), ),
+        (path, f'{package_name}.egg-info'),
         'requires.txt',
-        '\n'.join([
-            'ZODB3',
-            'setuptools',
-            'one',
-        ]),
+        '\n'.join(['ZODB3', 'setuptools', 'one']),
     )
 
     package = Package(path)
@@ -392,8 +350,7 @@ def test_unneeded_requirements_with_user_mapping2(
     report.unneeded_requirements()
     out, err = capsys.readouterr()
 
-    assert 'Unneeded requirements\n' \
-           '=====================' in out
+    assert 'Unneeded requirements\n=====================' in out
     assert 'ZODB3' in out
     assert 'one' in out
 
@@ -403,11 +360,7 @@ def test_unneeded_test_requirements(capsys, minimal_structure):
     write_source_file_at(
         (path, package_name + '.egg-info'),
         'requires.txt',
-        '\n'.join([
-            '[test]',
-            'pytest',
-            'mock',
-        ]),
+        '\n'.join(['[test]', 'pytest', 'mock']),
     )
 
     package = Package(path)
@@ -416,33 +369,22 @@ def test_unneeded_test_requirements(capsys, minimal_structure):
     report.unneeded_test_requirements()
     out, err = capsys.readouterr()
 
-    assert 'Unneeded test requirements\n' \
-           '==========================' in out
+    assert 'Unneeded test requirements\n==========================' in out
     assert 'pytest' in out
     assert 'mock' in out
 
 
-def test_unneeded_test_requirements_with_ignore_packages(
-    capsys,
-    minimal_structure
-):
+def test_unneeded_test_requirements_with_ignore_packages(capsys, minimal_structure):
     path, package_name = minimal_structure
     write_source_file_at(
         (path, package_name + '.egg-info'),
         'requires.txt',
-        '\n'.join([
-            '[test]',
-            'pytest',
-            'mock',
-        ]),
+        '\n'.join(['[test]', 'pytest', 'mock']),
     )
     write_source_file_at(
-        (path, ),
+        (path,),
         'pyproject.toml',
-        '\n'.join([
-            '[tool.dependencychecker]',
-            'ignore-packages = ["mock" ]',
-        ]),
+        '\n'.join(['[tool.dependencychecker]', 'ignore-packages = ["mock" ]']),
     )
 
     package = Package(path)
@@ -451,41 +393,30 @@ def test_unneeded_test_requirements_with_ignore_packages(
     report.unneeded_test_requirements()
     out, err = capsys.readouterr()
 
-    assert 'Unneeded test requirements\n' \
-           '==========================' in out
+    assert 'Unneeded test requirements\n==========================' in out
     assert 'pytest' in out
     assert 'mock' not in out
 
 
-def test_unneeded_test_requirements_with_user_mappings(
-    capsys,
-    minimal_structure
-):
+def test_unneeded_test_requirements_with_user_mappings(capsys, minimal_structure):
     path, package_name = minimal_structure
     write_source_file_at(
         (path, package_name + '.egg-info'),
         'requires.txt',
-        '\n'.join([
-            '[test]',
-            'pytest',
-            'ZODB3',
-        ]),
+        '\n'.join(['[test]', 'pytest', 'ZODB3']),
     )
     write_source_file_at(
-        (path, ),
+        (path,),
         'pyproject.toml',
-        '\n'.join([
-            '[tool.dependencychecker]',
-            '"ZODB3" = ["BTrees" ]',
-        ]),
+        '\n'.join(['[tool.dependencychecker]', '"ZODB3" = ["BTrees" ]']),
     )
     write_source_file_at(
-        (path, package_name, ),
+        (path, package_name),
         '__init__.py',
         '',
     )
     write_source_file_at(
-        (path, package_name, 'tests', ),
+        (path, package_name, 'tests'),
         '__init__.py',
         'from BTrees import Tree',
     )
@@ -496,8 +427,7 @@ def test_unneeded_test_requirements_with_user_mappings(
     report.unneeded_test_requirements()
     out, err = capsys.readouterr()
 
-    assert 'Unneeded test requirements\n' \
-           '==========================' in out
+    assert 'Unneeded test requirements\n==========================' in out
     assert 'pytest' in out
     assert 'ZODB3' not in out
     assert 'BTrees' not in out
@@ -536,13 +466,7 @@ def test_requirements_that_should_be_test_requirements(
     write_source_file_at(
         (path, package_name + '.egg-info'),
         'requires.txt',
-        '\n'.join([
-            'one',
-            'two',
-            '[test]',
-            'pytest',
-            'mock',
-        ]),
+        '\n'.join(['one', 'two', '[test]', 'pytest', 'mock']),
     )
 
     package = Package(path)
@@ -551,8 +475,10 @@ def test_requirements_that_should_be_test_requirements(
     report.requirements_that_should_be_test_requirements()
     out, err = capsys.readouterr()
 
-    assert 'Requirements that should be test requirements\n' \
-           '=============================================' in out
+    assert (
+        'Requirements that should be test requirements\n'
+        '=============================================' in out
+    )
     assert 'two' in out
 
 
@@ -569,30 +495,17 @@ def test_requirements_that_should_be_test_requirements_with_ignored_packages(
     write_source_file_at(
         (path, package_name, 'tests'),
         '__init__.py',
-        '\n'.join([
-            'import two',
-            'import three',
-        ])
+        '\n'.join(['import two', 'import three']),
     )
     write_source_file_at(
         (path, package_name + '.egg-info'),
         'requires.txt',
-        '\n'.join([
-            'one',
-            'two',
-            'three',
-            '[test]',
-            'pytest',
-            'mock',
-        ]),
+        '\n'.join(['one', 'two', 'three', '[test]', 'pytest', 'mock']),
     )
     write_source_file_at(
-        (path, ),
+        (path,),
         'pyproject.toml',
-        '\n'.join([
-            '[tool.dependencychecker]',
-            'ignore-packages = ["two" ]',
-        ]),
+        '\n'.join(['[tool.dependencychecker]', 'ignore-packages = ["two" ]']),
     )
 
     package = Package(path)
@@ -601,8 +514,10 @@ def test_requirements_that_should_be_test_requirements_with_ignored_packages(
     report.requirements_that_should_be_test_requirements()
     out, err = capsys.readouterr()
 
-    assert 'Requirements that should be test requirements\n' \
-           '=============================================' in out
+    assert (
+        'Requirements that should be test requirements\n'
+        '=============================================' in out
+    )
     assert 'three' in out
     assert 'two' not in out
 
@@ -620,30 +535,17 @@ def test_requirements_that_should_be_test_requirements_with_user_mappings(
     write_source_file_at(
         (path, package_name, 'tests'),
         '__init__.py',
-        '\n'.join([
-            'import two',
-            'import BTrees',
-        ])
+        '\n'.join(['import two', 'import BTrees']),
     )
     write_source_file_at(
         (path, package_name + '.egg-info'),
         'requires.txt',
-        '\n'.join([
-            'one',
-            'two',
-            'ZODB3',
-            '[test]',
-            'pytest',
-            'mock',
-        ]),
+        '\n'.join(['one', 'two', 'ZODB3', '[test]', 'pytest', 'mock']),
     )
     write_source_file_at(
-        (path, ),
+        (path,),
         'pyproject.toml',
-        '\n'.join([
-            '[tool.dependencychecker]',
-            '"ZODB3" = ["BTrees" ]',
-        ]),
+        '\n'.join(['[tool.dependencychecker]', '"ZODB3" = ["BTrees" ]']),
     )
 
     package = Package(path)
@@ -652,8 +554,10 @@ def test_requirements_that_should_be_test_requirements_with_user_mappings(
     report.requirements_that_should_be_test_requirements()
     out, err = capsys.readouterr()
 
-    assert 'Requirements that should be test requirements\n' \
-           '=============================================' in out
+    assert (
+        'Requirements that should be test requirements\n'
+        '=============================================' in out
+    )
     assert 'ZODB3' in out
     assert 'two' in out
     assert 'one' not in out
@@ -670,40 +574,22 @@ def test_requirements_that_should_be_test_requirements_with_user_mapping2(
     write_source_file_at(
         (path, package_name),
         '__init__.py',
-        '\n'.join([
-            'import one',
-            'import two',
-            'import part.of.meta',
-        ]),
+        '\n'.join(['import one', 'import two', 'import part.of.meta']),
     )
     write_source_file_at(
         (path, package_name, 'tests'),
         '__init__.py',
-        '\n'.join([
-            'import three',
-            'import four',
-            'import part.of.meta',
-        ])
+        '\n'.join(['import three', 'import four', 'import part.of.meta']),
     )
     write_source_file_at(
         (path, package_name + '.egg-info'),
         'requires.txt',
-        '\n'.join([
-            'one',
-            'two',
-            'three',
-            'meta-package',
-            '[test]',
-            'four',
-        ]),
+        '\n'.join(['one', 'two', 'three', 'meta-package', '[test]', 'four']),
     )
     write_source_file_at(
-        (path, ),
+        (path,),
         'pyproject.toml',
-        '\n'.join([
-            '[tool.dependencychecker]',
-            'meta-package = ["part.of.meta" ]',
-        ]),
+        '\n'.join(['[tool.dependencychecker]', 'meta-package = ["part.of.meta" ]']),
     )
 
     package = Package(path)
@@ -712,8 +598,10 @@ def test_requirements_that_should_be_test_requirements_with_user_mapping2(
     report.requirements_that_should_be_test_requirements()
     out, err = capsys.readouterr()
 
-    assert 'Requirements that should be test requirements\n' \
-           '=============================================' in out
+    assert (
+        'Requirements that should be test requirements\n'
+        '=============================================' in out
+    )
     assert 'three' in out
     assert 'one' not in out
     assert 'two' not in out
